@@ -1,5 +1,8 @@
 [+ autogen5 template +]
 [+INCLUDE (string-append "licenses/" (get "License") ".tpl") \+]
+[+INCLUDE (string-append "indent.tpl") \+]
+# [+INVOKE EMACS-MODELINE MODE="Python" \+]
+[+INVOKE START-INDENT\+]
 #!/usr/local/bin/python2.7
 #
 # main.py
@@ -8,3 +11,4 @@
 [+INVOKE LICENSE-DESCRIPTION PFX="# " PROGRAM=(get "Name") OWNER=(get "Author") \+]
 
 print "Hello World!"
+[+INVOKE END-INDENT\+]
